┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/dolphinviewcontainer.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/dolphinviewcontainer.h')
-rw-r--r--src/dolphinviewcontainer.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/dolphinviewcontainer.h b/src/dolphinviewcontainer.h
index 417aa27c9..6abeab4b0 100644
--- a/src/dolphinviewcontainer.h
+++ b/src/dolphinviewcontainer.h
@@ -110,9 +110,9 @@ public slots:
void setUrl(const KUrl& url);
/**
* Popups the filter bar above the status bar if \a show is true.
*/
- void showFilterBar(bool show);
+ void setFilterBarVisible(bool visible);
signals:
/**
@@ -110,9 +110,9 @@ public slots:
void setUrl(const KUrl& url);
/**
- * Popups the filter bar above the status bar if \a show is true.
+ * Popups the filter bar above the status bar if \a visible is true.
*/